Index: src/lemon/concept/undir_graph.h
===================================================================
--- src/lemon/concept/undir_graph.h	(revision 962)
+++ src/lemon/concept/undir_graph.h	(revision 986)
@@ -48,6 +48,6 @@
 
 	Node n;
-	n = graph.head(ue);
-	n = graph.tail(ue);
+	n = graph.target(ue);
+	n = graph.source(ue);
 
 	graph.first(ue);

Index: src/lemon/concept/graph.h
===================================================================
--- src/lemon/concept/graph.h	(revision 961)
+++ src/lemon/concept/graph.h	(revision 986)
@@ -364,14 +364,14 @@
 //       EdgeIt& first(EdgeIt& i) const { return i; }
 
-//       ///Gives back the head node of an edge.
-
-//       ///Gives back the head node of an edge.
-//       ///
-//       Node head(Edge) const { return INVALID; }
-//       ///Gives back the tail node of an edge.
-
-//       ///Gives back the tail node of an edge.
-//       ///
-//       Node tail(Edge) const { return INVALID; }
+//       ///Gives back the target node of an edge.
+
+//       ///Gives back the target node of an edge.
+//       ///
+//       Node target(Edge) const { return INVALID; }
+//       ///Gives back the source node of an edge.
+
+//       ///Gives back the source node of an edge.
+//       ///
+//       Node source(Edge) const { return INVALID; }
   
 //       ///Gives back the \e id of a node.
@@ -539,6 +539,6 @@
 // 	Edge e;
 // 	e=INVALID;
-// 	n=G.tail(e);
-// 	n=G.head(e);
+// 	n=G.source(e);
+// 	n=G.target(e);
 //       }
 //       // id tests
@@ -666,6 +666,6 @@
 //       ///Add a new edge to the graph.
 
 //       ///Add a new edge to the graph with tail node \c t
 //       ///and head node \c h.
 //       ///\return the new edge.
 //       Edge addEdge(Node h, Node t) { return INVALID; }
@@ -801,6 +801,6 @@
       void nextInEdge(Edge &e) const { }
 
-      Node head(Edge) const { return Node(); }
-      Node tail(Edge) const { return Node(); }
+      Node target(Edge) const { return Node(); }
+      Node source(Edge) const { return Node(); }
       
 
@@ -666,6 +666,6 @@
 //       ///Add a new edge to the graph.
 
-//       ///Add a new edge to the graph with tail node \c t
-//       ///and head node \c h.
+//       ///Add a new edge to the graph with source node \c t
+//       ///and target node \c h.
 //       ///\return the new edge.
 //       Edge addEdge(Node h, Node t) { return INVALID; }
Index: src/lemon/concept/graph_component.h
===================================================================
--- src/lemon/concept/graph_component.h	(revision 980)
+++ src/lemon/concept/graph_component.h	(revision 986)
@@ -243,15 +243,15 @@
       };
 
-      ///Gives back the head node of an edge.
-
-      ///Gives back the head node of an edge.
-      ///
-      Node head(const Edge&) const { return INVALID;}
-
-      ///Gives back the tail node of an edge.
-
-      ///Gives back the tail node of an edge.
-      ///
-      Node tail(const Edge&) const { return INVALID;}
+      ///Gives back the target node of an edge.
+
+      ///Gives back the target node of an edge.
+      ///
+      Node target(const Edge&) const { return INVALID;}
+
+      ///Gives back the source node of an edge.
+
+      ///Gives back the source node of an edge.
+      ///
+      Node source(const Edge&) const { return INVALID;}
     };
 
@@ -273,6 +273,6 @@
 	  Node n;
 	  Edge e;
-	  n = graph.tail(e);
-	  n = graph.head(e);
+	  n = graph.source(e);
+	  n = graph.target(e);
 	}      
       }
Index: src/lemon/concept/path.h
===================================================================
--- src/lemon/concept/path.h	(revision 967)
+++ src/lemon/concept/path.h	(revision 986)
@@ -67,10 +67,10 @@
       /// Starting point of the path.
       /// Returns INVALID if the path is empty.
-      GraphNode/*It*/ head() const {return INVALID;}
+      GraphNode/*It*/ target() const {return INVALID;}
       /// \brief End point of the path.
       ///
       /// End point of the path.
       /// Returns INVALID if the path is empty.
-      GraphNode/*It*/ tail() const {return INVALID;}
+      GraphNode/*It*/ source() const {return INVALID;}
 
       /// \brief First NodeIt/EdgeIt.
@@ -81,15 +81,15 @@
       It& first(It &i) const { return i=It(*this); }
 
       /// \brief The head of an edge.
       ///
       /// Returns node iterator pointing to the head node of the
       /// given edge iterator.
-      NodeIt head(const EdgeIt& e) const {return INVALID;}
-
-      /// \brief The tail of an edge.
-      ///
-      /// Returns node iterator pointing to the tail node of the
+      NodeIt target(const EdgeIt& e) const {return INVALID;}
+
+      /// \brief The source of an edge.
+      ///
+      /// Returns node iterator pointing to the source node of the
       /// given edge iterator.
-      NodeIt tail(const EdgeIt& e) const {return INVALID;}
+      NodeIt source(const EdgeIt& e) const {return INVALID;}
 
 
@@ -81,15 +81,15 @@
       It& first(It &i) const { return i=It(*this); }
 
-      /// \brief The head of an edge.
-      ///
-      /// Returns node iterator pointing to the head node of the
+      /// \brief The target of an edge.
+      ///
+      /// Returns node iterator pointing to the target node of the
       /// given edge iterator.
Index: src/lemon/concept/sym_graph.h
===================================================================
--- src/lemon/concept/sym_graph.h	(revision 959)
+++ src/lemon/concept/sym_graph.h	(revision 986)
@@ -451,14 +451,14 @@
       SymEdgeIt& first(SymEdgeIt& i) const { return i; }
 
-      ///Gives back the head node of an edge.
-
-      ///Gives back the head node of an edge.
-      ///
-      Node head(Edge) const { return INVALID; }
-      ///Gives back the tail node of an edge.
-
-      ///Gives back the tail node of an edge.
-      ///
-      Node tail(Edge) const { return INVALID; }
+      ///Gives back the target node of an edge.
+
+      ///Gives back the target node of an edge.
+      ///
+      Node target(Edge) const { return INVALID; }
+      ///Gives back the source node of an edge.
+
+      ///Gives back the source node of an edge.
+      ///
+      Node source(Edge) const { return INVALID; }
   
       ///Gives back the first node of an symmetric edge.
@@ -466,10 +466,10 @@
       ///Gives back the first node of an symmetric edge.
       ///
-      Node head(SymEdge) const { return INVALID; }
+      Node target(SymEdge) const { return INVALID; }
       ///Gives back the second node of an symmetric edge.
 
       ///Gives back the second node of an symmetric edge.
       ///
-      Node tail(SymEdge) const { return INVALID; }
+      Node source(SymEdge) const { return INVALID; }
       ///Gives back the \e id of a node.
 
@@ -608,6 +608,6 @@
       ///Add a new edge to the graph.
 
       ///Add a new symmetric edge to the graph with tail node \c t
       ///and head node \c h.
       ///\return the new edge.
       SymEdge addEdge(Node h, Node t) { return INVALID; }
@@ -608,6 +608,6 @@
       ///Add a new edge to the graph.
 
-      ///Add a new symmetric edge to the graph with tail node \c t
-      ///and head node \c h.
+      ///Add a new symmetric edge to the graph with source node \c t
+      ///and target node \c h.
       ///\return the new edge.
       SymEdge addEdge(Node h, Node t) { return INVALID; }